==> wtframework-0.2.0.tar.gz: wtframework-0.2.0/wtframework/wtf/testobjects/test_watchers.py <==
##########################################################################
#This file is part of WTFramework. 
#
#    WTFramework is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    WTFramework is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with WTFramework.  If not, see <http://www.gnu.org/licenses/>.
##########################################################################


from wtframework.wtf.config import WTF_CONFIG_READER
from wtframework.wtf.testobjects.interfaces import TestWatcher
from wtframework.wtf.web.capture import WebScreenShotUtil
from wtframework.wtf.web.webdriver import WTF_WEBDRIVER_MANAGER
import datetime
import re


class DelayedTestFailTestWatcher(TestWatcher):
    '''
    Delayed test fail test watcher allows for the ability to call wrapped assertions.
    Assertions fails will be stored in a list, then on_test_pass(), any failures stored 
    in the list will immediately be thrown causing the test to fail.
    
    Note: this will immediately throw an exception on_test_pass(), any actions that use 
    on_test_pass() that you would like to execute should be added before this test watcher.
    '''

    def __init__(self):
        '''
        Constructor
        '''
        self.exception_list = []


    def delay_failure(self, function, additional_debug_info):
        """
        Wrap a assertion call to delay test failure till after the test.
        Usage: delayed_fail_watcher.delay_failure( lambda: self.assertEquals(5, x) )
        
        @param function: Function reference of lambda expression to be evaluated. 
        @param current_execution_frame: Pass it a frame to include in the exception to 
            aid in debugging.
        @return: None if succeeds.  Returns a reference the exception if failed.
        """
        try:
            #run assertion.
            function()

            return None
        except Exception as e:

            if not additional_debug_info:
                self.exception_list.append(e)
            else:
                self.exception_list.append((e,additional_debug_info))
            return e

    def on_test_pass(self, test_case, test_result):
        if len(self.exception_list) > 0:
            raise DelayedTestFailure(self.exception_list)



class DelayedTestFailure(AssertionError):
    "Thrown at the end of a test if there are test failure."




class CaptureScreenShotOnErrorTestWatcher(TestWatcher):
    '''
    Catures screenshot on error if the config setting is enabled.
    '''


    def __init__(self, webdriver_provider=None, screenshot_util=None):
        '''
        Constructor
        '''
        if WTF_CONFIG_READER.get("selenium.take_screenshot", True):
            self.capture_screenshot = True
        else:
            self.capture_screenshot = False
        
        if webdriver_provider == None:
            self._webdriver_provider = WTF_WEBDRIVER_MANAGER
        else:
            self._webdriver_provider = webdriver_provider

        if screenshot_util == None:
            self._screenshot_util = WebScreenShotUtil
        else:
            self._screenshot_util = screenshot_util 
            

    def on_test_failure(self, test_case, test_result, exception):
        """
        Runs when an unexpected test failure occurs
        @param test_case: Test case to pass in.
        @param test_case: wtframework.wtf.testobjects.TestCase
        """
        if self.capture_screenshot: self.__take_screenshot_if_webdriver_open__(test_case)
    
    def on_test_error(self, test_case, test_result, exception):
        """
        Runs when a test error occcurs.
        @param test_case: Test case to pass in.
        @param test_case: wtframework.wtf.testobjects.TestCase
        """
        if self.capture_screenshot: self.__take_screenshot_if_webdriver_open__(test_case)


    def __generate_screenshot_filename__(self, testcase):
        '''
        Get the class name and timestamp for generating filenames
        @return: File Name.
        @rtype: str
        '''
        fname = type(testcase).__name__ + "_" + testcase._testMethodName
        fname = re.sub("[^a-zA-Z_]+", "_", fname)
        fmt='%y-%m-%d_%H.%M.%S_{fname}'
        return datetime.datetime.now().strftime(fmt).format(fname=fname)
    
    def __take_screenshot_if_webdriver_open__(self, testcase):
        '''
        Take a screenshot if webdriver is open.
        '''
        if self._webdriver_provider.is_driver_available():
            try:
                name = self.__generate_screenshot_filename__(testcase)
                self._screenshot_util.take_screenshot(self._webdriver_provider.get_driver(), name)
                print "Screenshot taken:" + name
            except Exception as e:
                print "Unable to take screenshot. Reason: " + e.message + str(type(e))

==> wtframework-0.2.1.tar.gz: wtframework-0.2.1/wtframework/wtf/testobjects/test_watchers.py <==
##########################################################################
#This file is part of WTFramework. 
#
#    WTFramework is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    WTFramework is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with WTFramework.  If not, see <http://www.gnu.org/licenses/>.
##########################################################################


from wtframework.wtf.config import WTF_CONFIG_READER
from wtframework.wtf.testobjects.interfaces import TestWatcher
from wtframework.wtf.web.capture import WebScreenShotUtil
from wtframework.wtf.web.webdriver import WTF_WEBDRIVER_MANAGER
import datetime
import re


class DelayedTestFailTestWatcher(TestWatcher):
    '''
    Delayed test fail test watcher allows for the ability to call wrapped assertions.
    Assertions fails will be stored in a list, then on_test_pass(), any failures stored 
    in the list will immediately be thrown causing the test to fail.
    
    Note: this will immediately throw an exception on_test_pass(), any actions that use 
    on_test_pass() that you would like to execute should be added before this test watcher.
    '''

    def __init__(self):
        '''
        Constructor
        '''
        self.exception_list = []


    def delay_failure(self, function, additional_debug_info):
        """
        Wrap a assertion call to delay test failure till after the test.
        Usage: delayed_fail_watcher.delay_failure( lambda: self.assertEquals(5, x) )
        
        @param function: Function reference of lambda expression to be evaluated. 
        @param current_execution_frame: Pass it a frame to include in the exception to 
            aid in debugging.
        @return: None if succeeds.  Returns a reference the exception if failed.
        """
        try:
            #run assertion.
            function()

            return None
        except Exception as e:

            if not additional_debug_info:
                self.exception_list.append(e)
            else:
                self.exception_list.append((e,additional_debug_info))
            return e

    def on_test_pass(self, test_case, test_result):
        if len(self.exception_list) > 0:
            raise DelayedTestFailure(*tuple(self.exception_list))



class DelayedTestFailure(AssertionError):
    "Thrown at the end of a test if there are test failure."
    
    def __init__(self, *args, **kwargs):
        super(DelayedTestFailure, self).__init__(*args, **kwargs)
        self.exception_list = args
    
    #Overriding __str__ to make the error message easier to read.
    def __str__(self, *args, **kwargs):
        exception_string = ""
        count = 0
        for exception_entry in self.exception_list:
            count += 1
            exception_string += "\nError {0}: ".format(count) + exception_entry.__str__()
        
        return AssertionError.__str__(self, *args, **kwargs) + exception_string



class CaptureScreenShotOnErrorTestWatcher(TestWatcher):
    '''
    Catures screenshot on error if the config setting is enabled.
    '''


    def __init__(self, webdriver_provider=None, screenshot_util=None):
        '''
        Constructor
        '''
        if WTF_CONFIG_READER.get("selenium.take_screenshot", True):
            self.capture_screenshot = True
        else:
            self.capture_screenshot = False
        
        if webdriver_provider == None:
            self._webdriver_provider = WTF_WEBDRIVER_MANAGER
        else:
            self._webdriver_provider = webdriver_provider

        if screenshot_util == None:
            self._screenshot_util = WebScreenShotUtil
        else:
            self._screenshot_util = screenshot_util 
            

    def on_test_failure(self, test_case, test_result, exception):
        """
        Runs when an unexpected test failure occurs
        @param test_case: Test case to pass in.
        @param test_case: wtframework.wtf.testobjects.TestCase
        """
        if self.capture_screenshot: self.__take_screenshot_if_webdriver_open__(test_case)
    
    def on_test_error(self, test_case, test_result, exception):
        """
        Runs when a test error occcurs.
        @param test_case: Test case to pass in.
        @param test_case: wtframework.wtf.testobjects.TestCase
        """
        if self.capture_screenshot: self.__take_screenshot_if_webdriver_open__(test_case)


    def __generate_screenshot_filename__(self, testcase):
        '''
        Get the class name and timestamp for generating filenames
        @return: File Name.
        @rtype: str
        '''
        fname = type(testcase).__name__ + "_" + testcase._testMethodName
        fname = re.sub("[^a-zA-Z_]+", "_", fname)
        #Trim test case name incase it's too long.
        fname = fname[:20]
        fmt='%y-%m-%d_%H.%M.%S_{fname}'
        return datetime.datetime.now().strftime(fmt).format(fname=fname)
    
    def __take_screenshot_if_webdriver_open__(self, testcase):
        '''
        Take a screenshot if webdriver is open.
        '''
        if self._webdriver_provider.is_driver_available():
            try:
                name = self.__generate_screenshot_filename__(testcase)
                self._screenshot_util.take_screenshot(self._webdriver_provider.get_driver(), name)
                print "Screenshot taken:" + name
            except Exception as e:
                print "Unable to take screenshot. Reason: " + e.message + str(type(e))
